Provides a small wrapper around rlang::abort() to standardize
error classes within the package for precise testing and user handling.
Usage
abort_zse(message, class = character())Provides a small wrapper around rlang::abort() to standardize
error classes within the package for precise testing and user handling.
abort_zse(message, class = character())