Skip to contents

Take a tibble containing the comments from a Zoom recording transcript and return a tibble that adds rows for any time between transcribed comments, labeled with the dead_air_name provided (or the default value of 'dead_air'). The resulting tibble will have rows accounting for the time from the beginning of the first comment to the end of the last one.

Usage

add_dead_air_rows(df = NULL, dead_air_name = "dead_air")

Arguments

df

A tibble containing transcript comments with columns: name, start, end, comment

dead_air_name

Name to use for dead air periods. Defaults to 'dead_air'.

Value

A tibble with rows added for dead air periods