Skip to contents

Convenience wrapper to process a set of .transcript.vtt files from a folder, compute engagement metrics, and optionally write outputs.

Usage

analyze_transcripts(
  transcripts_folder = NULL,
  names_to_exclude = c("dead_air"),
  write = FALSE,
  output_path = NULL
)

Arguments

transcripts_folder

Path to folder containing transcript files

names_to_exclude

Vector of names to exclude from analysis (default: "dead_air")

write

Whether to write results to file (default: FALSE)

output_path

Explicit path for the output file when write = TRUE.

Value

A tibble with speaker-level engagement metrics for the discovered transcript files. When write = TRUE, the same metrics are also written to output_path after export privacy policies are applied.