Accepts the same inputs as future implementation but aborts with a clear message. This keeps the API future-proof without enabling behavior now.
Accepts the same inputs as future implementation but aborts with a clear message. This keeps the API future-proof without enabling behavior now.