Skip to contents

Summarize which identifier columns were present and how many values were masked.

Usage

privacy_audit(
  data = NULL,
  id_columns = c("preferred_name", "name", "first_last", "name_raw", "student_id",
    "email")
)

Arguments

data

A tibble containing the data to audit

id_columns

Vector of column names to check for identifiers (default: common name columns)

Value

A tibble with one row per detected identifier column and the fields column, values, non_empty, and masked_estimate, summarizing the technical masking state of the supplied data.