Load a Zoom recording transcript and return tibble containing the comments from a Zoom recording transcript
Value
A tibble with one row per parsed WebVTT cue and columns describing
speaker name, cue text, start and end times, duration, word count, and
source transcript. Returns NULL when the file is empty.
Details
Original code posted by Conor Healy:
https://ucbischool.slack.com/archives/C02A36407K9/p1631855705002000 Addition
of wordcount by Brooks Ambrose:
https://gist.github.com/brooksambrose/1a8a673eb3bf884c1868ad4d80f08246
Examples
# Load a sample transcript from the package's extdata directory
transcript_file <- system.file("extdata/test_transcripts/intro_statistics_week1.vtt",
package = "engager"
)
load_zoom_transcript(transcript_file_path = transcript_file)
#> # A tibble: 56 × 8
#> transcript_file comment_num name comment start end duration wordcount
#> <chr> <chr> <chr> <chr> <time> <time> <drtn> <int>
#> 1 intro_statistics_… 1 Prof… Good m… 00'00" 00'02" 2 secs 8
#> 2 intro_statistics_… 2 Prof… Today … 00'02" 00'05" 3 secs 9
#> 3 intro_statistics_… 3 Prof… Let me… 00'05" 00'08" 3 secs 12
#> 4 intro_statistics_… 4 Stud… I've u… 00'08" 00'12" 4 secs 7
#> 5 intro_statistics_… 5 Stud… I've d… 00'12" 00'15" 3 secs 9
#> 6 intro_statistics_… 6 Stud… I'm co… 00'15" 00'18" 3 secs 8
#> 7 intro_statistics_… 7 Prof… That's… 00'18" 00'22" 4 secs 8
#> 8 intro_statistics_… 8 Prof… Let me… 00'22" 00'26" 4 secs 10
#> 9 intro_statistics_… 9 Prof… Here w… 00'26" 00'30" 4 secs 9
#> 10 intro_statistics_… 10 Prof… The fi… 00'30" 00'35" 5 secs 11
#> # ℹ 46 more rows